[telepathy-gabble/master] Add group flags for remove-with-message.

Will Thompson will.thompson at collabora.co.uk
Thu Aug 13 10:15:25 PDT 2009


---
 src/media-channel.c |   11 +++++++++--
 1 files changed, 9 insertions(+), 2 deletions(-)

diff --git a/src/media-channel.c b/src/media-channel.c
index 1c04a79..7959b86 100644
--- a/src/media-channel.c
+++ b/src/media-channel.c
@@ -322,8 +322,15 @@ gabble_media_channel_constructor (GType type, guint n_props,
       TP_CHANNEL_GROUP_CHANGE_REASON_NONE);
   tp_intset_destroy (set);
 
-  /* We implement the 0.17.6 properties correctly */
-  tp_group_mixin_change_flags (obj, TP_CHANNEL_GROUP_FLAG_PROPERTIES, 0);
+  /* We implement the 0.17.6 properties correctly, and can include a message
+   * when ending a call.
+   */
+  tp_group_mixin_change_flags (obj,
+      TP_CHANNEL_GROUP_FLAG_PROPERTIES |
+      TP_CHANNEL_GROUP_FLAG_MESSAGE_REMOVE |
+      TP_CHANNEL_GROUP_FLAG_MESSAGE_REJECT |
+      TP_CHANNEL_GROUP_FLAG_MESSAGE_RESCIND,
+      0);
 
   /* Set up Google relay related properties */
   jf = priv->conn->jingle_factory;
-- 
1.5.6.5




More information about the telepathy-commits mailing list